==> com.idenfy.idenfySdk-1.0.7.1-sources.jar: com/idenfy/idenfySdk/CoreSdkInitialization/IdenfySettings.java <==
package com.idenfy.idenfySdk.CoreSdkInitialization;

import android.content.Context;
import android.graphics.Typeface;
import android.os.Parcel;
import android.os.Parcelable;
import android.support.annotation.ColorRes;
import android.support.annotation.DrawableRes;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.idenfy.idenfySdk.helpers.enums.FontEnum;
import com.idenfySdk.R;

public class IdenfySettings implements Parcelable {

    public boolean optionalResultsChecking = false;
    private @NonNull
    String publicKey;
    private @NonNull
    String clientId;
    private @NonNull
    String firstName;
    private @NonNull
    String lastName;
    private String selectedCountry;
    private Typeface font;
    private @ColorRes
    int buttonTextColor;
    private @ColorRes
    int primaryTextColor;
    private @DrawableRes
    @ColorRes
    int backgroundDrawable;
    private @DrawableRes
    int successDrawable;
    private @DrawableRes
    int errorDrawable;
    private @DrawableRes
    int logoDrawable;
    private @Nullable
    String token;
    private @Nullable
    Boolean handleResultsChecking = false;

    private @Nullable
    boolean isNewWayOfIdentification = true;

    protected IdenfySettings(Parcel in) {
        optionalResultsChecking = in.readByte() != 0;
        publicKey = in.readString();
        clientId = in.readString();
        firstName = in.readString();
        lastName = in.readString();
        selectedCountry = in.readString();
        buttonTextColor = in.readInt();
        primaryTextColor = in.readInt();
        backgroundDrawable = in.readInt();
        successDrawable = in.readInt();
        errorDrawable = in.readInt();
        logoDrawable = in.readInt();
        token = in.readString();
        byte tmpHandleResultsChecking = in.readByte();
        handleResultsChecking = tmpHandleResultsChecking == 0 ? null : tmpHandleResultsChecking == 1;
        isNewWayOfIdentification = in.readByte() != 0;
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeByte((byte) (optionalResultsChecking ? 1 : 0));
        dest.writeString(publicKey);
        dest.writeString(clientId);
        dest.writeString(firstName);
        dest.writeString(lastName);
        dest.writeString(selectedCountry);
        dest.writeInt(buttonTextColor);
        dest.writeInt(primaryTextColor);
        dest.writeInt(backgroundDrawable);
        dest.writeInt(successDrawable);
        dest.writeInt(errorDrawable);
        dest.writeInt(logoDrawable);
        dest.writeString(token);
        dest.writeByte((byte) (handleResultsChecking == null ? 0 : handleResultsChecking ? 1 : 2));
        dest.writeByte((byte) (isNewWayOfIdentification ? 1 : 0));
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<IdenfySettings> CREATOR = new Creator<IdenfySettings>() {
        @Override
        public IdenfySettings createFromParcel(Parcel in) {
            return new IdenfySettings(in);
        }

        @Override
        public IdenfySettings[] newArray(int size) {
            return new IdenfySettings[size];
        }
    };

    @Nullable
    public boolean isNewWayOfIdentification() {
        return isNewWayOfIdentification;
    }

    public void setNewWayOfIdentification(@Nullable boolean newWayOfIdentification) {
        isNewWayOfIdentification = newWayOfIdentification;
    }

    public Typeface getIdenfyFont(FontEnum fontEnum) {
        if (this.font != null) {
            return this.font;
        }

        return fontEnum.getTypeface();
    }

    public void setFont(Typeface font) {
        this.font = font;
    }


    @Nullable
    public Boolean getHandleResultsChecking() {
        return handleResultsChecking;
    }

    public IdenfySettings(@NonNull String token, @NonNull Context context) {
        this("", "", "", "", "LTU", context);
        this.token = token;
    }

    public IdenfySettings(@NonNull String publicKey, @NonNull String clientId,
                          @NonNull String firstName, @NonNull String lastName,
                          @NonNull String selectedCountry, @NonNull Context context
    )

    {
        this.publicKey = publicKey;
        this.clientId = clientId;
        this.firstName = firstName;
        this.lastName = lastName;
        logoDrawable = R.drawable.idenfy_logo_new_good;
        token = null;
    }

    @Nullable
    public String getToken() {
        return token;
    }


    public String getSelectedCountry() {
        return selectedCountry;
    }

    public void setSelectedCountry(@NonNull String selectedCountry) {
        this.selectedCountry = selectedCountry;
    }

    void setHandleResultsChecking(boolean optionalHandeling) {
        this.handleResultsChecking = optionalHandeling;
    }


    @Override
    public String toString() {
        return "IdenfySettings{" +
                "publicKey='" + publicKey + '\'' +
                ", clientId='" + clientId + '\'' +
                ", firstName='" + firstName + '\'' +
                ", lastName='" + lastName + '\'' +
                ", selectedCountry='" + selectedCountry + '\'' +
                ", font=" + font +
                ", buttonTextColor=" + buttonTextColor +
                ", primaryTextColor=" + primaryTextColor +
                ", backgroundDrawable=" + backgroundDrawable +
                ", successDrawable=" + successDrawable +
                ", errorDrawable=" + errorDrawable +
                ", logoDrawable=" + logoDrawable +
                ", token='" + token + '\'' +
                ", handleResultsChecking=" + handleResultsChecking +
                '}';
    }
}

==> com.idenfy.idenfySdk-1.0.7.2-sources.jar: com/idenfy/idenfySdk/CoreSdkInitialization/IdenfySettings.java <==
package com.idenfy.idenfySdk.CoreSdkInitialization;

import android.content.Context;
import android.graphics.Typeface;
import android.os.Parcel;
import android.os.Parcelable;
import android.support.annotation.ColorRes;
import android.support.annotation.DrawableRes;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.idenfy.idenfySdk.helpers.enums.FontEnum;
import com.idenfySdk.R;

public class IdenfySettings implements Parcelable {

    public boolean optionalResultsChecking = false;
    private String selectedCountry;
    private Typeface font;
    private @Nullable
    String token;
    private @Nullable
    Boolean handleResultsChecking = false;

    private @Nullable
    String selectedSdkCustomLocale = null;

    private @Nullable
    boolean isNewWayOfIdentification = true;
    private String customFontPath;

    protected IdenfySettings(Parcel in) {
        optionalResultsChecking = in.readByte() != 0;
        selectedCountry = in.readString();
        token = in.readString();
        byte tmpHandleResultsChecking = in.readByte();
        handleResultsChecking = tmpHandleResultsChecking == 0 ? null : tmpHandleResultsChecking == 1;
        selectedSdkCustomLocale = in.readString();
        isNewWayOfIdentification = in.readByte() != 0;
        customFontPath = in.readString();
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeByte((byte) (optionalResultsChecking ? 1 : 0));
        dest.writeString(selectedCountry);
        dest.writeString(token);
        dest.writeByte((byte) (handleResultsChecking == null ? 0 : handleResultsChecking ? 1 : 2));
        dest.writeString(selectedSdkCustomLocale);
        dest.writeByte((byte) (isNewWayOfIdentification ? 1 : 0));
        dest.writeString(customFontPath);
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<IdenfySettings> CREATOR = new Creator<IdenfySettings>() {
        @Override
        public IdenfySettings createFromParcel(Parcel in) {
            return new IdenfySettings(in);
        }

        @Override
        public IdenfySettings[] newArray(int size) {
            return new IdenfySettings[size];
        }
    };

    public String getCustomFontPath()
    {
        return customFontPath;
    }


    @Nullable
    public boolean isNewWayOfIdentification() {
        return isNewWayOfIdentification;
    }

    public void setNewWayOfIdentification(@Nullable boolean newWayOfIdentification) {
        isNewWayOfIdentification = newWayOfIdentification;
    }

    public Typeface getIdenfyFont(FontEnum fontEnum) {
        if (this.font != null) {
            return this.font;
        }

        return fontEnum.getTypeface();
    }

    public void setFont(String font) {

        this.customFontPath = font;
    }


    @Nullable
    public Boolean getHandleResultsChecking() {
        return handleResultsChecking;
    }

    public IdenfySettings(@NonNull String token, @NonNull Context context) {
        this.token = token;
    }
    @Nullable
    public String getToken() {
        return token;
    }


    public void setCustomLocale(String locale)
    {
        selectedSdkCustomLocale = locale;
    }
    public String getCustomLocale()
    {

        return selectedSdkCustomLocale;
    }
    public String getSelectedCountry() {
        return selectedCountry;
    }

    public void setSelectedCountry(@NonNull String selectedCountry) {
        this.selectedCountry = selectedCountry;
    }

    void setHandleResultsChecking(boolean optionalHandeling) {
        this.handleResultsChecking = optionalHandeling;
    }


    @Override
    public String toString() {
        return "IdenfySettings{" +
                ", selectedCountry='" + selectedCountry + '\'' +
                ", font=" + font +
                ", token='" + token + '\'' +
                ", handleResultsChecking=" + handleResultsChecking +
                '}';
    }

    public void setCustomTypeface(Typeface idenfyFont) {

            font = idenfyFont;
    }
}
